@@ -5,6 +5,8 @@ require 'addressable/uri'
 
 module MikuTwitter::APIShortcuts
 
+  RELATIONAL_DEFAULT = {count: 5000}.freeze
+
   def self.defshortcut(method_name, api, parser, key_convert = {}, defaults = {})
     if block_given?
       define_method(method_name, &yield(api, parser))
@@ -50,10 +52,10 @@ module MikuTwitter::APIShortcuts
   defcursorpager :followers_id, 'followers/ids', :paged_ids, :ids, id: :user_id
 
   def followings(args = {})
-    idlist2userlist(friends_id(args)) end
+    idlist2userlist(friends_id(RELATIONAL_DEFAULT.merge(args))) end
 
   def followers(args = {})
-    idlist2userlist(followers_id(args)) end
+    idlist2userlist(followers_id(RELATIONAL_DEFAULT.merge(args))) end
 
   def direct_messages(args = {})
     (self/:direct_messages).direct_messages({:count => 200}.merge(args)) end
@@ -170,18 +172,10 @@ module MikuTwitter::APIShortcuts
   #
 
   def userstream(params={}, &chunk)
-    begin
-      stream("https://userstream.twitter.com/1.1/user.json", params, &chunk)
-    rescue Exception => e
-      warn e
-      raise e end end
+    stream("https://userstream.twitter.com/1.1/user.json", params, &chunk) end
 
   def filter_stream(params={}, &chunk)
-    begin
-      stream("https://stream.twitter.com/1.1/statuses/filter.json", params, &chunk)
-    rescue Exception => e
-      warn e
-      raise e end end
+    stream("https://stream.twitter.com/1.1/statuses/filter.json", params, &chunk) end
 
   private
 
