@@ -38,19 +38,19 @@ module Gtk
                Gdk::EventButton, Gtk::TreePath, Gtk::TreeViewColumn,
                Integer, Integer)
 
-    def signal_do_button_press_event(event, path, column, cell_x, cell_y)
+    def signal_do_button_press_event(e, path, column, cell_x, cell_y)
     end
 
-    def signal_do_button_release_event(event, path, column, cell_x, cell_y)
+    def signal_do_button_release_event(e, path, column, cell_x, cell_y)
     end
 
-    def signal_do_motion_notify_event(event, path, column, cell_x, cell_y)
+    def signal_do_motion_notify_event(e, path, column, cell_x, cell_y)
     end
 
-    def signal_do_leave_notify_event(event, path, column, cell_x, cell_y)
+    def signal_do_leave_notify_event(e, path, column, cell_x, cell_y)
     end
 
-    def signal_do_click(event, path, column, cell_x, cell_y)
+    def signal_do_click(e, path, column, cell_x, cell_y)
     end
 
     def tree=(tree)
@@ -163,11 +163,14 @@ module Gtk
         record.miracle_painter.clicked(cell_x, cell_y, e) if record
         false }
       ssc(:button_press_event, @tree){ |r, e, path, column, cell_x, cell_y|
-        if e.button == 1
-          record = @tree.get_record(path)
-          if record
-            last_pressed = record.miracle_painter
-            last_pressed.pressed(cell_x, cell_y) end end
+        record = @tree.get_record(path)
+        if record
+          last_pressed = record.miracle_painter
+          if e.button == 1
+            last_pressed.pressed(cell_x, cell_y) end
+          Delayer.new(:ui_response) {
+            Plugin::GUI.keypress(::Gtk::buttonname([e.event_type, e.button, e.state]), @tree.imaginary) }
+        end
         false }
       ssc(:button_release_event, @tree){ |r, e, path, column, cell_x, cell_y|
         if e.button == 1 and last_pressed
@@ -206,4 +209,3 @@ module Gtk
 
   end
 end
-
