@@ -8,27 +8,47 @@ require_if_exist 'Win32API'
 class GLib::Instantiatable
   # signal_connectと同じだが、イベントが呼ばれるたびにselfが削除されたGLib Objectでない場合のみブロックを実行する点が異なる。
   # また、relatedの中に既に削除されたGLib objectがあれば、ブロックを実行せずにシグナルをselfから切り離す。
+  # ==== Args
+  # [signal] イベント名か、イベントとブロックの連想配列
+  #   Symbol|String :: イベントの名前
+  #   Hash :: キーにイベント名、値に呼び出すブロックを持つHash
+  # [*related] GLib::Object ブロック実行時、これらのうちどれか一つでも削除されていたらブロックを実行しない
+  # [&proc] signalがイベントの名前の場合、イベントが発生したらこのブロックが呼ばれる
+  # ==== Return
+  # signal_connectと同じ
   def safety_signal_connect(signal, *related, &proc)
-    type_strict proc => :call
-    related.each{ |gobj|
-      raise ArgumentError.new(gobj.to_s) unless gobj.is_a?(GLib::Object) }
-    if related
-      sid = signal_connect(signal){ |*args|
-        if not(destroyed?)
-          if (related.any?(&:destroyed?))
-            signal_handler_disconnect(sid)
-          else
-            proc.call(*args) end end }
+    case signal
+    when Hash
+      signal.each{ |name, callback|
+        safety_signal_connect(name, *related, &callback) }
+    when String, Symbol
+      related.each{ |gobj|
+        raise ArgumentError.new(gobj.to_s) unless gobj.is_a?(GLib::Object) }
+      if related
+        sid = signal_connect(signal){ |*args|
+          if not(destroyed?)
+            if (related.any?(&:destroyed?))
+              signal_handler_disconnect(sid)
+            else
+              proc.call(*args) end end }
+      else
+        signal_connect(signal){ |*args|
+          if not(destroyed?)
+            proc.call(*args) end } end
     else
-      signal_connect(signal){ |*args|
-        if not(destroyed?)
-          proc.call(*args) end } end end
+      raise ArgumentError, "First argument should Hash, String, or Symbol." end end
   alias ssc safety_signal_connect
 
-  alias signal_connect_unrecording signal_connect
-  def signal_connect(name, *other_args, &proc)
-    signal_connect_unrecording(name, *other_args, &__track(&proc))
-  end
+  # safety_signal_connect を、イベントが発生した最初の一度だけ呼ぶ
+  def safety_signal_connect_atonce(signal, *related, &proc)
+    called = false
+    sid = ssc(signal, *related) { |*args|
+      unless called
+        called = true
+        signal_handler_disconnect(sid)
+        proc.call(args) end }
+    sid end
+  alias ssc_atonce safety_signal_connect_atonce
 
   private
   def __track(&proc)
@@ -53,10 +73,32 @@ class Gtk::Object
     Gtk.main_quit end end
 
 module Gtk
+  KonamiCache = File.expand_path(File.join(Environment::CACHE, 'core', 'konami.png'))
   class << self
-    attr_accessor :exception
+    attr_accessor :exception, :konami
+    attr_reader :konami_image
   end
 
+  self.konami = false
+
+  def self.konami_load
+    return if @konami
+    if FileTest.exist? KonamiCache
+      @konami_image = Gdk::Pixbuf.new(KonamiCache, 41, 52)
+      @konami = true
+    else
+      Thread.new do
+        begin
+          tmpfile = File.join(Environment::TMPDIR, '600eur')
+          open('http://mikutter.hachune.net/img/konami.png', 'rb') { |konami|
+            open(tmpfile, 'wb'){ |cache| IO.copy_stream konami, cache } }
+          FileUtils.mkdir_p(File.dirname(KonamiCache))
+          FileUtils.mv(tmpfile, KonamiCache)
+          @konami_image = Gdk::Pixbuf.new(KonamiCache, 41, 52)
+          @konami = true
+        rescue => exception
+          error exception end end end end
+
   def self.keyname(key)
     type_strict key => Array
     if key.empty? or key[0] == 0 or not key.all?(&ret_nth)
@@ -68,7 +110,33 @@ module Gtk
       r << 'Alt + ' if (key[1] & Gdk::Window::MOD1_MASK) != 0
       r << 'Super + ' if (key[1] & Gdk::Window::SUPER_MASK) != 0
       r << 'Hyper + ' if (key[1] & Gdk::Window::HYPER_MASK) != 0
-      return r + Gdk::Keyval.to_name(key[0]) end end end
+      return r + Gdk::Keyval.to_name(key[0]) end end
+
+  def self.buttonname(key)
+    type_strict key => Array
+    type, button, state = key
+    if key.empty? or type == 0 or not key.all?(&ret_nth)
+      return '(割り当てなし)'
+    else
+      r = ""
+      r << 'Control + ' if (state & Gdk::Window::CONTROL_MASK) != 0
+      r << 'Shift + ' if (state & Gdk::Window::SHIFT_MASK) != 0
+      r << 'Alt + ' if (state & Gdk::Window::MOD1_MASK) != 0
+      r << 'Super + ' if (state & Gdk::Window::SUPER_MASK) != 0
+      r << 'Hyper + ' if (state & Gdk::Window::HYPER_MASK) != 0
+      r << "Button #{button} "
+      case type
+      when Gdk::Event::BUTTON_PRESS
+          r << 'Click'
+      when Gdk::Event::BUTTON2_PRESS
+          r << 'Double Click'
+      when Gdk::Event::BUTTON3_PRESS
+          r << 'Triple Click'
+      else
+        return '(割り当てなし)' end
+      return r end end
+
+end
 
 =begin rdoc
 = Gtk::Lock Ruby::Gnome2の排他制御
@@ -143,6 +211,11 @@ class Gtk::Clipboard
   def self.copy(t)
     Gtk::Clipboard.get(Gdk::Atom.intern('CLIPBOARD', true)).text = t
   end
+
+  # クリップボードから文字列を取得する
+  def self.paste
+    Gtk::Clipboard.get(Gdk::Atom.intern('CLIPBOARD', true)).wait_for_text
+  end
 end
 
 class Gtk::Dialog
@@ -160,7 +233,7 @@ class Gtk::Dialog
   end
 
   # Yes,Noの二択の質問を表示する。
-  # OKボタンが押されたらtrue、それ以外が押されたらfalseを返す
+  # YESボタンが押されたらtrue、それ以外が押されたらfalseを返す
   def self.confirm(message)
     Gtk::Lock.synchronize{
       dialog = Gtk::MessageDialog.new(nil,
