@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-miquire :core, 'configloader', 'environment', 'delayer', 'event', 'event_listener', 'event_filter'
-miquire :lib, "instance_storage"
+miquire :core, 'configloader', 'environment', 'event', 'event_listener', 'event_filter'
+miquire :lib, "instance_storage", 'delayer'
 
 # プラグインの本体。
 # DSLを提供し、イベントやフィルタの管理をする
@@ -207,11 +207,11 @@ class Plugin
   # filter_?name :: add_event_filter(name)
   def method_missing(method, *args, &proc)
     case method.to_s
-    when /^on_?(.+)$/
+    when /\Aon_?(.+)\Z/
        add_event($1.to_sym, &proc)
-    when /^filter_?(.+)$/
+    when /\Afilter_?(.+)\Z/
        add_event_filter($1.to_sym, &proc)
-    when /^hook_?(.+)$/
+    when /\Ahook_?(.+)\Z/
       add_event_hook($1.to_sym, &proc)
     else
       super end end
