@@ -26,7 +26,7 @@ class Plugin::Achievement::Achievement
       @events.each{ |e| plugin.detach(*e) }
       @events.clear
       if @options[:depends] and not @options[:depends].empty?
-        unachievements = Plugin.filtering(:unachievements, {}).first.values_at(*@options[:depends]).select &ret_nth
+        unachievements = Plugin.filtering(:unachievements, {}).first.values_at(*@options[:depends]).select(&ret_nth)
         notice unachievements
         if not unachievements.empty?
           on_achievement_took do |ach|
@@ -54,9 +54,9 @@ class Plugin::Achievement::Achievement
   def method_missing(method, *args, &block)
     result = plugin.__send__(method, *args, &block)
     case method.to_s
-    when /^on_?(.*)$/
+    when /\Aon_?(.*)\Z/
       @events << [$1.to_sym, result]
-    when /^filter_?(.*)$/
+    when /\Afilter_?(.*)\Z/
       @events << [$1.to_sym, result]
     end
     result
@@ -95,18 +95,26 @@ Plugin.create :achievement do
     end
   end
 
-  defactivity "achievement", "実績"
+  defactivity "achievement", _("実績")
+
+  defachievement(:register_account,
+                 description: _("Twitterアカウントをmikutterに登録しました。これでTwitterが捗る"),
+                 hidden: true
+                 ) do |ach|
+    on_service_registered do |_| ach.take! end
+  end
 
   defachievement(:open_setting,
-                 description: "設定画面で、mikutterをカスタマイズしましょう。",
-                 hint: "画面右下にあるレンチのアイコンをクリックしよう"
+                 description: _("設定画面で、mikutterをカスタマイズしましょう。"),
+                 hint: _("画面右下にあるレンチのアイコンをクリックしよう"),
+                 depends: [:register_account, :tutorial]
                  ) do |ach|
     on_open_setting do ach.take! end
   end
 
   defachievement(:display_requirements,
-                 description: "ヾ(＠⌒ー⌒＠)ノ",
-                 hint: "https://github.com/toshia/display_requirements",
+                 description: _("ヾ(＠⌒ー⌒＠)ノ"),
+                 hint: _("https://github.com/toshia/display_requirements"),
                  depends: [:open_setting]
                  ) do |ach|
     Delayer.new {
@@ -114,16 +122,17 @@ Plugin.create :achievement do
       ach.take! unless dr and defined? dr.rotten? } end
 
   defachievement(:multipane,
-                 description: "新規ペインを追加コマンドでペインを増やせます",
-                 hint: "タブを右クリックして、「新規ペインに移動」をクリックしてみよう"
+                 description: _("新規ペインを追加コマンドでペインを増やせます"),
+                 hint: _("タブを右クリックして、「新規ペインに移動」をクリックしてみよう"),
+                 depends: [:register_account, :tutorial]
                  ) do |ach|
     on_gui_pane_join_window do |pane, window|
       if window.children.inject(0){|i,s| i + (s.is_a?(Plugin::GUI::Pane) ? 1 : 0) } >= 2
         ach.take! end end end
 
   defachievement(:move_pane,
-                 description: "タブを別のペインにドラッグすれば、そのペインに移動できます",
-                 hint: "二つ以上ペインがある時に、タブを別のペインにドラッグ＆ドロップしてみましょう",
+                 description: _("タブを別のペインにドラッグすれば、そのペインに移動できます"),
+                 hint: _("二つ以上ペインがある時に、タブを別のペインにドラッグ＆ドロップしてみましょう"),
                  depends: [:multipane]
                  ) do |ach|
     on_after_gui_tab_reordered do |tab|
@@ -133,21 +142,33 @@ Plugin.create :achievement do
       ach.take! end end
 
   defachievement(:bugreporter,
-                 description: "クラッシュレポートの報告ありがとうございます",
-                 hidden: true
+                 description: _("クラッシュレポートの報告ありがとうございます"),
+                 hidden: true,
+                 depends: [:register_account, :tutorial]
                  ) do |ach|
     on_send_bugreport do |report|
       ach.take! end end
 
+  defachievement(:hidden_command,
+                 description: "隠しコマンドを入力した",
+                 hidden: true,
+                 depends: [:tutorial]
+                 ) do |ach|
+    on_konami_activate do
+      ach.take! end end
+
   Delayer.new do
     unachievements = Plugin.filtering(:unachievements, {}).first.reject{ |k, v| v.hidden? }
-    if not unachievements.empty?
-      if not unachievements.empty?
-        not_achieved = unachievements.values[rand(unachievements.size)].notachieved_parent
-        activity :achievement, not_achieved.hint end end end
+    unless unachievements.empty?
+      not_achieved = unachievements.values[rand(unachievements.size)].notachieved_parent
+      unless not_achieved.hidden?
+        if Mopt.debug?
+          activity :achievement, "#{not_achieved.hint}\n(slug: #{not_achieved.slug})"
+        else
+          activity :achievement, not_achieved.hint end end end end
 
   on_achievement_took do |achievement|
-    activity :achievement, "実績 #{achievement.slug.to_s} を達成しました！おめでとう♪" end
+    activity :achievement, (_("実績 %s を達成しました！おめでとう♪") % achievement.slug.to_s) end
 
 end
 
