@@ -9,7 +9,7 @@ Plugin.create :command do
       last_active_pane[i_window.slug] = i_pane end end
 
   command(:copy_selected_region,
-          name: 'コピー',
+          name: _('コピー'),
           condition: Plugin::Command[:HasOneMessage, :TimelineTextSelected],
           visible: true,
           icon: Skin.get("copy.png"),
@@ -17,7 +17,7 @@ Plugin.create :command do
     ::Gtk::Clipboard.copy(opt.widget.selected_text(opt.messages.first)) end
 
   command(:copy_description,
-          name: '本文をコピー',
+          name: _('本文をコピー'),
           condition: Plugin::Command[:HasOneMessage],
           visible: true,
           icon: Skin.get("copy_all.png"),
@@ -25,7 +25,7 @@ Plugin.create :command do
     ::Gtk::Clipboard.copy(opt.messages.first.to_show) end
 
   command(:reply,
-          name: '返信',
+          name: _('返信'),
           condition: Plugin::Command[:CanReplyAll],
           visible: true,
           icon: Skin.get("reply.png"),
@@ -34,7 +34,7 @@ Plugin.create :command do
                                     subreplies: opt.messages.map(&:message)) end
 
   command(:reply_all,
-          name: '全員に返信',
+          name: _('全員に返信'),
           condition: Plugin::Command[:CanReplyAll],
           visible: true,
           icon: Skin.get("reply.png"),
@@ -44,22 +44,22 @@ Plugin.create :command do
                                     exclude_myself: true) end
 
   command(:legacy_retweet,
-          name: '引用',
+          name: _('引用'),
           condition: Plugin::Command[:HasOneMessage, :CanReplyAll],
           visible: true,
           role: :timeline) do |opt|
     opt.widget.create_reply_postbox(opt.messages.first.message, retweet: true) end
 
   command(:retweet,
-          name: 'リツイート',
-          condition: Plugin::Command[:CanReTweetAll],
+          name: _('リツイート'),
+          condition: Plugin::Command[:CanReTweetAny],
           visible: true,
           icon: Skin.get("retweet.png"),
           role: :timeline) do |opt|
-    opt.messages.select{ |x| not x.from_me? }.each(&:retweet) end
+    opt.messages.select(&:retweetable?).reject{ |m| m.retweeted_by_me? Service.primary }.each(&:retweet) end
 
   command(:delete_retweet,
-          name: 'リツイートをキャンセル',
+          name: _('リツイートをキャンセル'),
           condition: Plugin::Command[:IsReTweetedAll],
           visible: true,
           icon: Skin.get("retweet_cancel.png"),
@@ -69,15 +69,15 @@ Plugin.create :command do
       retweet.destroy if retweet and ::Gtk::Dialog.confirm("このつぶやきのリツイートをキャンセルしますか？\n\n#{m.to_show}") } end
 
   command(:favorite,
-          name: 'ふぁぼふぁぼする',
-          condition: Plugin::Command[:CanFavoriteAll],
+          name: _('ふぁぼふぁぼする'),
+          condition: Plugin::Command[:CanFavoriteAny],
           visible: true,
           icon: Skin.get("unfav.png"),
           role: :timeline) do |opt|
-    opt.messages.each(&:favorite) end
+    opt.messages.select(&:favoritable?).reject{ |m| m.favorited_by_me? Service.primary }.each(&:favorite) end
 
   command(:delete_favorite,
-          name: 'あんふぁぼ',
+          name: _('あんふぁぼ'),
           condition: Plugin::Command[:IsFavoritedAll],
           visible: true,
           icon: Skin.get("fav.png"),
@@ -85,38 +85,38 @@ Plugin.create :command do
     opt.messages.each(&:unfavorite) end
 
   command(:delete,
-          name: '削除',
+          name: _('削除'),
           condition: Plugin::Command[:IsMyMessageAll],
           visible: true,
           icon: Skin.get("close.png"),
           role: :timeline) do |opt|
     opt.messages.each { |m|
-      m.destroy if ::Gtk::Dialog.confirm("失った信頼はもう戻ってきませんが、本当にこのつぶやきを削除しますか？\n\n#{m.to_show}") } end
+      m.destroy if ::Gtk::Dialog.confirm(_('失った信頼はもう戻ってきませんが、本当にこのつぶやきを削除しますか？') + "\n\n#{m.to_show}") } end
 
   command(:select_prev,
-          name: '一つ上のメッセージを選択',
+          name: _('一つ上のメッセージを選択'),
           condition: ret_nth,
           visible: false,
           role: :timeline) do |opt|
     Plugin.call(:gui_timeline_move_cursor_to, opt.widget, :prev) end
 
   command(:select_next,
-          name: '一つ下のメッセージを選択',
+          name: _('一つ下のメッセージを選択'),
           condition: ret_nth,
           visible: false,
           role: :timeline) do |opt|
     Plugin.call(:gui_timeline_move_cursor_to, opt.widget, :next) end
 
   command(:post_it,
-          name: '投稿する',
+          name: _('投稿する'),
           condition: Plugin::Command[:Editable],
-          visible: false,
+          visible: true,
           icon: Skin.get("post.png"),
           role: :postbox) do |opt|
     opt.widget.post_it! end
 
   command(:google_search,
-          name: 'ggrks',
+          name: _('ggrks'),
           condition: Plugin::Command[:HasOneMessage, :TimelineTextSelected],
           visible: true,
           icon: "https://www.google.co.jp/images/google_favicon_128.png",
@@ -124,7 +124,7 @@ Plugin.create :command do
     ::Gtk::openurl("http://www.google.co.jp/search?q=" + URI.escape(opt.widget.selected_text(opt.messages.first)).to_s) end
 
   command(:open_link,
-          name: 'リンクを開く',
+          name: _('リンクを開く'),
           condition: Plugin::Command[:HasOneMessage] & lambda{ |opt|
             opt.messages[0].entity.to_a.any? {|u| [:urls, :media].include?(u[:slug]) } },
           visible: true,
@@ -139,8 +139,17 @@ Plugin.create :command do
         end
       ::Gtk::TimeLine.openurl(url) if url } end
 
+  command(:copy_link,
+          name: _('リンクをコピー'),
+          condition: Plugin::Command[:HasOneMessage] & lambda{ |opt|
+            opt.messages[0].entity.to_a.any? {|u| u[:slug] == :urls } },
+          visible: true,
+          role: :timeline) do |opt|
+    opt.messages[0].entity.to_a.each {|u|
+    ::Gtk::Clipboard.copy(u[:url]) if u[:slug] == :urls } end
+
   command(:new_pane,
-          name: '新規ペインに移動',
+          name: _('新規ペインに移動'),
           condition: lambda{ |opt|
             pane = opt.widget.parent
             notice "pane: #{pane}"
@@ -160,7 +169,7 @@ Plugin.create :command do
   end
 
   command(:close,
-          name: 'タブを閉じる',
+          name: _('タブを閉じる'),
           condition: lambda{ |opt|
             opt.widget.deletable },
           visible: true,
@@ -170,7 +179,7 @@ Plugin.create :command do
   end
 
   command(:focus_right_tab,
-          name: '右のタブを選択',
+          name: _('右のタブを選択'),
           condition: lambda{ |opt| true },
           visible: false,
           role: :tab) do |opt|
@@ -178,7 +187,7 @@ Plugin.create :command do
   end
 
   command(:focus_left_tab,
-          name: '左のタブを選択',
+          name: _('左のタブを選択'),
           condition: lambda{ |opt| true },
           visible: false,
           role: :tab) do |opt|
@@ -186,7 +195,7 @@ Plugin.create :command do
   end
 
   command(:focus_right_pane,
-          name: '右のペインを選択',
+          name: _('右のペインを選択'),
           condition: lambda{ |opt| true },
           visible: false,
           role: :pane) do |opt|
@@ -194,7 +203,7 @@ Plugin.create :command do
   end
 
   command(:focus_left_pane,
-          name: '左のペインを選択',
+          name: _('左のペインを選択'),
           condition: lambda{ |opt| true },
           visible: false,
           role: :pane) do |opt|
@@ -202,7 +211,7 @@ Plugin.create :command do
   end
 
   command(:focus_to_postbox,
-          name: '投稿ボックスにフォーカス',
+          name: _('投稿ボックスにフォーカス'),
           condition: lambda{ |opt|
             if opt.widget.respond_to? :active_chain
               not opt.widget.active_chain.last.is_a? Plugin::GUI::Postbox
@@ -214,7 +223,7 @@ Plugin.create :command do
   end
 
   command(:focus_to_tab,
-          name: 'タブにフォーカス',
+          name: _('タブにフォーカス'),
           condition: lambda{ |opt| true },
           visible: false,
           role: :postbox) do |opt|
@@ -222,7 +231,7 @@ Plugin.create :command do
   end
 
   command(:timeline_scroll_to_top,
-          name: 'タイムラインの一番上にジャーンプ！',
+          name: _('タイムラインの一番上にジャーンプ！'),
           condition: lambda{ |opt| true },
           visible: false,
           role: :timeline) do |opt|
