@@ -24,13 +24,13 @@ module Plugin::DirectMessage
       if iter
         Plugin.call(:show_profile, Service.primary, iter[Gtk::InnerUserList::COL_USER]) end }
 
-    tab(:directmessage, "DM") do
+    tab(:directmessage, _("DM")) do
       set_icon Skin.get("directmessage.png")
       expand
       nativewidget ul
     end
 
-    profiletab(:directmessage, "DM") do
+    profiletab(:directmessage, _("DM")) do
       set_icon Skin.get("directmessage.png")
       nativewidget Plugin.create(:direct_message).dm_list_widget(user)
     end
@@ -57,14 +57,14 @@ module Plugin::DirectMessage
 
     def rewind
       service = Service.primary_service
-      Deferred.when(service.direct_messages, service.sent_direct_messages).next{ |dm, sent|
-        result = dm + sent
-        Plugin.call(:direct_messages, service, result) if result and not result.empty?
-      }.trap{ |e|
-        error e
-        raise e
-      }.terminate
-    end
+      if service
+        Deferred.when(service.direct_messages, service.sent_direct_messages).next{ |dm, sent|
+          result = dm + sent
+          Plugin.call(:direct_messages, service, result) if result and not result.empty?
+        }.trap{ |e|
+          error e
+          raise e
+        }.terminate end end
 
     def add_dm(dm, user)
       unless @dm_store[user[:id]].any?{ |stored| stored[:id] == dm[:id] }
@@ -77,7 +77,7 @@ module Plugin::DirectMessage
 
     def dm_list_widget(user)
       container = ::Gtk::VBox.new
-      tl = DirectMessage.new
+      tl = DirectMessage.new(self)
 
       scrollbar = ::Gtk::VScrollbar.new(tl.vadjustment)
       model = tl.model
@@ -114,7 +114,7 @@ module Plugin::DirectMessage
         detach(:direct_message, event)
       }
       mumbles = ::Gtk::VBox.new(false, 0)
-      postbox = ::Gtk::PostBox.new(Sender.new(Service.primary_service, user), :postboxstorage => mumbles, :delegate_other => true)
+      postbox = ::Gtk::PostBox.new(Sender.new(user), :postboxstorage => mumbles, :delegate_other => true)
       mumbles.pack_start(postbox)
       container.closeup(mumbles).add(::Gtk::HBox.new.add(tl).closeup(scrollbar))
       container
