@@ -17,6 +17,7 @@ require File.expand_path File.join(File.dirname(__FILE__), 'tab_toolbar')
 require File.expand_path File.join(File.dirname(__FILE__), 'delayer')
 require File.expand_path File.join(File.dirname(__FILE__), 'slug_dictionary')
 require File.expand_path File.join(File.dirname(__FILE__), 'mainloop')
+require File.expand_path File.join(File.dirname(__FILE__), 'konami_watcher')
 
 Plugin.create :gtk do
   @slug_dictionary = Plugin::Gtk::SlugDictionary.new # widget_type => {slug => Gtk}
@@ -28,7 +29,7 @@ Plugin.create :gtk do
   # PostBoxとか複数のペインを持つための処理が入るので、Gtk::MikutterWindowクラスを新設してそれを使う
   on_window_created do |i_window|
     notice "create window #{i_window.slug.inspect}"
-    window = ::Gtk::MikutterWindow.new(i_window)
+    window = ::Gtk::MikutterWindow.new(i_window, self)
     @slug_dictionary.add(i_window, window)
     window.title = i_window.name
     window.set_size_request(240, 240)
@@ -85,7 +86,7 @@ Plugin.create :gtk do
       pane.set_tab_pos(TABPOS[val]) unless pane.destroyed? }
     pane.ssc(:page_reordered){ |this, tabcontainer, index|
       notice "on_pane_created: page_reordered: #{i_pane.inspect}"
-      window_order_save_request(i_pane.parent) if i_pane.parent
+        Plugin.call(:rewind_window_order, i_pane.parent) if i_pane.parent
       i_tab = tabcontainer.i_tab
       notice "tabcontainer #{tabcontainer} => #{i_tab.inspect}"
       if i_tab
@@ -94,13 +95,11 @@ Plugin.create :gtk do
       false }
     pane.ssc(:switch_page){ |this, page, pagenum|
       if pagenum == pane.page
-        i_pane.set_active_child(pane.get_nth_page(pagenum).i_tab, true)
-      else
-        notice "switch_page: pagenum(#{pagenum}) != pane.page(#{pane.page})" end }
+        i_pane.set_active_child(pane.get_nth_page(pagenum).i_tab, true) end }
     pane.signal_connect(:page_added){ |this, tabcontainer, index|
       type_strict tabcontainer => ::Gtk::TabContainer
       notice "on_pane_created: page_added: #{i_pane.inspect}"
-      window_order_save_request(i_pane.parent) if i_pane.parent
+      Plugin.call(:rewind_window_order, i_pane.parent) if i_pane.parent
       i_tab = tabcontainer.i_tab
       next false if i_tab.parent == i_pane
       notice "on_pane_created: reparent"
@@ -121,6 +120,7 @@ Plugin.create :gtk do
   # タブ作成。
   # タブには実体が無いので、タブのアイコンのところをGtk::EventBoxにしておいて、それを実体ということにしておく
   on_tab_created do |i_tab|
+    notice "tab_created: #{i_tab.slug.inspect}"
     tab = create_tab(i_tab)
     if @tabs_promise[i_tab.slug]
       @tabs_promise[i_tab.slug].call(tab)
@@ -130,6 +130,7 @@ Plugin.create :gtk do
     create_pane(i_profile) end
 
   on_profiletab_created do |i_profiletab|
+    notice "profiletab_created: #{i_profiletab.slug.inspect}"
     create_tab(i_profiletab) end
 
   # タブを作成する
@@ -138,7 +139,6 @@ Plugin.create :gtk do
   # ==== Return
   # Tab(Gtk::EventBox)
   def create_tab(i_tab)
-    notice "create tab #{i_tab.slug.inspect}"
     tab = ::Gtk::EventBox.new.tooltip(i_tab.name)
     @slug_dictionary.add(i_tab, tab)
     tab_update_icon(i_tab)
@@ -148,11 +148,14 @@ Plugin.create :gtk do
     }
     tab.ssc(:key_press_event){ |widget, event|
       Plugin::GUI.keypress(::Gtk::keyname([event.keyval ,event.state]), i_tab) }
-    tab.ssc(:button_press_event) { |this, e|
-      if e.button == 3
-        Plugin::GUI::Command.menu_pop(i_tab) end
+    tab.ssc(:button_press_event) { |this, event|
+      if event.button == 3
+        Plugin::GUI::Command.menu_pop(i_tab)
+      else
+        Plugin::GUI.keypress(::Gtk::buttonname([event.event_type, event.button, event.state]), i_tab)
+      end
       false }
-    tab.ssc(:destroy){
+    tab.ssc(:destroy) {
       i_tab.destroy
       false }
     tab.show_all end
@@ -172,31 +175,19 @@ Plugin.create :gtk do
   # Gtk::TimeLine
   on_timeline_created do |i_timeline|
     notice "create timeline #{i_timeline.slug.inspect}"
-    timeline = ::Gtk::TimeLine.new(i_timeline)
-    @slug_dictionary.add(i_timeline, timeline)
-    handler = {
-      key_press_event: timeline_key_press_event(i_timeline),
-      focus_in_event: timeline_focus_in_event(i_timeline),
-      destroy: lambda{ |this| timeline_hook_events(timeline, handler) } }
-    timeline_hook_events(timeline, handler)
-    timeline.ssc(:destroy){
-      i_timeline.destroy
-      false }
-    timeline.show_all
+    gtk_timeline = ::Gtk::TimeLine.new(i_timeline)
+    @slug_dictionary.add(i_timeline, gtk_timeline)
+    gtk_timeline.tl.ssc(key_press_event: timeline_key_press_event(i_timeline),
+                        focus_in_event:  timeline_focus_in_event(i_timeline),
+                        destroy:         timeline_destroy_event(i_timeline))
+    gtk_timeline.show_all
   end
 
-  # Gtk::TimeLine::InnerTL にたいして、イベントのリスナを登録する。
-  # ==== Args
-  # [gtk_timeline] 対象となる Gtk::TimeLine のインスタンス
-  def timeline_hook_events(gtk_timeline, handler)
-    handler.each{ |event_name, callback|
-      gtk_timeline.tl.ssc(event_name, gtk_timeline, &callback) } end
-
   # Timelineウィジェットのfocus_in_eventのコールバックを返す
   # ==== Args
   # [i_timeline] タイムラインのインターフェイス
   # ==== Return
-  # コールバック関数
+  # Proc
   def timeline_focus_in_event(i_timeline)
     lambda { |this, event|
       if this.focus?
@@ -209,13 +200,22 @@ Plugin.create :gtk do
   # ==== Args
   # [i_timeline] タイムラインのインターフェイス
   # ==== Return
-  # コールバック関数
+  # Proc
   def timeline_key_press_event(i_timeline)
     lambda { |widget, event|
       Plugin::GUI.keypress(::Gtk::keyname([event.keyval ,event.state]), i_timeline) } end
 
+  # Timelineウィジェットのdestroyのコールバックを返す
+  # ==== Args
+  # [i_timeline] タイムラインのインターフェイス
+  # ==== Return
+  # Proc
+  def timeline_destroy_event(i_timeline)
+    lambda { |this|
+      i_timeline.destroy
+      false } end
+
   on_gui_pane_join_window do |i_pane, i_window|
-    puts "gui_pane_join_window #{i_pane.slug.inspect}, #{i_window.slug.inspect}"
     window = widgetof(i_window)
     pane = widgetof(i_pane)
     if pane.parent
@@ -257,7 +257,7 @@ Plugin.create :gtk do
         w_child.parent.remove(w_child)
         widget_join_tab(i_tab, w_child) }
       tab.show_all end
-    window_order_save_request(i_pane.parent) if i_pane.parent
+    Plugin.call(:rewind_window_order, i_pane.parent) if i_pane.parent
   end
 
   on_gui_timeline_join_tab do |i_timeline, i_tab|
@@ -283,6 +283,16 @@ Plugin.create :gtk do
     postbox.post.ssc(:focus_in_event) {
       i_postbox.active!(true, true)
       false }
+
+    postbox.post.ssc("populate-popup"){ |widget, menu|
+      (event, items) = Plugin::GUI::Command.get_menu_items(i_postbox)
+
+      menu.append(Gtk::SeparatorMenuItem.new) if items.length != 0
+      menu2 = Gtk::ContextMenu.new(*items).build!(i_postbox, event, menu)
+      menu2.show_all 
+
+      true }
+
     postbox.post.ssc('key_press_event'){ |widget, event|
       Plugin::GUI.keypress(::Gtk::keyname([event.keyval ,event.state]), i_postbox) }
     postbox.post.ssc(:destroy){
@@ -293,6 +303,11 @@ Plugin.create :gtk do
   on_gui_tab_change_icon do |i_tab|
     tab_update_icon(i_tab) end
 
+  on_tab_toolbar_rewind do |i_tab_toolbar|
+    tab_toolbar = widgetof(i_tab_toolbar)
+    if tab_toolbar
+      tab_toolbar.set_button end end
+
   on_gui_contextmenu do |event, contextmenu|
     widget = widgetof(event.widget)
     if widget
@@ -345,6 +360,7 @@ Plugin.create :gtk do
         if pane
           pane.n_pages.times{ |pagenum|
             if widget == pane.get_tab_label(pane.get_nth_page(pagenum))
+              Plugin.call(:rewind_window_order, i_widget.parent.parent)
               pane.remove_page(pagenum)
               break end } end
       else
@@ -374,7 +390,10 @@ Plugin.create :gtk do
     widget_join_tab(i_profiletab, container.show_all) end
 
   on_gui_window_rewindstatus do |i_window, text, expire|
-    statusbar = @slug_dictionary.get(Plugin::GUI::Window, :default).statusbar
+    window = @slug_dictionary.get(Plugin::GUI::Window, :default)
+    if not window
+      next end
+    statusbar = window.statusbar
     cid = statusbar.get_context_id("system")
     mid = statusbar.push(cid, text)
     notice "rewind statusbar to #{text}, #{expire.inspect}, #{cid}"
@@ -420,6 +439,10 @@ Plugin.create :gtk do
       Gdk::MiraclePainter.findbymessage(message).each{ |mp|
         mp.on_modify } end end
 
+  on_konami_activate do
+    Gtk.konami_load
+  end
+
   filter_gui_postbox_input_editable do |i_postbox, editable|
     postbox = widgetof(i_postbox)
     if postbox
@@ -474,7 +497,13 @@ Plugin.create :gtk do
     return false if not i_pane
     pane = widgetof(i_pane)
     return false if not pane
+    is_tab = i_tab.is_a?(Plugin::GUI::Tab)
+    is_parmatab = is_tab and not(i_tab.temporary_tab?)
+    has_child = is_parmatab and not(i_tab.children.any?{ |child|
+                                      not child.is_a? Plugin::GUI::TabToolbar })
     notice "widget_join_tab: #{widget} join #{i_tab}"
+    if has_child
+      Plugin.call(:rewind_window_order, i_pane.parent) end
     container_index = pane.get_tab_pos_by_tab(tab)
     if container_index
       container = pane.get_nth_page(container_index)
@@ -486,7 +515,7 @@ Plugin.create :gtk do
     container.ssc(:key_press_event){ |w, event|
       Plugin::GUI.keypress(::Gtk::keyname([event.keyval ,event.state]), i_tab) }
     container.pack_start(widget, i_tab.pack_rule[container.children.size])
-    pane.insert_page_menu(where_should_insert_it(i_tab, pane.children.map(&:i_tab), i_pane.children), container, tab)
+    pane.append_page(container, tab)
     pane.set_tab_reorderable(container, true).set_tab_detachable(container, true)
     true end
 
@@ -494,6 +523,7 @@ Plugin.create :gtk do
     type_strict i_tab => Plugin::GUI::TabLike
     tab = widgetof(i_tab)
     if tab
+      tab.tooltip(i_tab.name)
       tab.remove(tab.child) if tab.child
       if i_tab.icon.is_a?(String)
         tab.add(::Gtk::WebIcon.new(i_tab.icon, 24, 24).show)
@@ -528,27 +558,21 @@ Plugin.create :gtk do
     pane.show_all end
 
   # ウィンドウ内のペイン、タブの現在の順序を設定に保存する
-  # ==== Args
-  # [i_window] ウィンドウ
-  def window_order_save_request(i_window)
-    notice "window_order_save_request: #{i_window.inspect}"
-    type_strict i_window => Plugin::GUI::Window
-    Delayer.new do
-      panes_order = {}
-      i_window.children.each{ |i_pane|
-        if i_pane.is_a? Plugin::GUI::Pane
-          tab_order = []
-          pane = widgetof(i_pane)
-          if pane
-            pane.n_pages.times{ |page_num|
-              i_widget = find_implement_widget_by_gtkwidget(pane.get_tab_label(pane.get_nth_page(page_num)))
-              tab_order << i_widget.slug if i_widget } end
-          panes_order[i_pane.slug] = tab_order if not tab_order.empty? end }
-      ui_tab_order = (UserConfig[:ui_tab_order] || {}).melt
-      ui_tab_order[i_window.slug] = panes_order
-      UserConfig[:ui_tab_order] = ui_tab_order
-    end
-  end
+  on_rewind_window_order do |i_window|
+    panes_order = {}
+    i_window.children.each{ |i_pane|
+      if i_pane.is_a? Plugin::GUI::Pane
+        tab_order = []
+        pane = widgetof(i_pane)
+        if pane
+          pane.n_pages.times{ |page_num|
+            i_widget = find_implement_widget_by_gtkwidget(pane.get_tab_label(pane.get_nth_page(page_num)))
+            if i_widget and not i_widget.temporary_tab? and i_widget.children.any?{ |child| not child.is_a? Plugin::GUI::TabToolbar }
+              tab_order << i_widget.slug end } end
+        panes_order[i_pane.slug] = tab_order if not tab_order.empty? end }
+    ui_tab_order = (UserConfig[:ui_tab_order] || {}).melt
+    ui_tab_order[i_window.slug] = panes_order
+    UserConfig[:ui_tab_order] = ui_tab_order end
 
   # ペインを順序リストから削除する
   # ==== Args
